{% extends './base_template.html' %}
{% load fragments %}
{% block content %}
<hgroup>
  <h2>About</h2>
  <h3>Should be able to display some messages via Django.</h3>
</hgroup>
{% endblock content %}
